@@ -424,6 +424,18 @@ class SemanticTransformer(nn.Module):
             last_logit_indices += 1
 
         output = mask_out_after_eos_id(output, self.pad_id, include_eos = include_eos_in_output)
+
+        has_eos_mask = (output == self.eos_id).any(dim = -1)
+
+        if not has_eos_mask.all():
+            append_eos_or_pad = torch.where(
+                has_eos_mask,
+                torch.full((batch, 1), self.pad_id, dtype = torch.long, device = device),
+                torch.full((batch, 1), self.eos_id, dtype = torch.long, device = device),
+            )
+
+            output = torch.cat((output, append_eos_or_pad), dim = -1)
+
         return output
 
     def forward_with_cond_scale(
@@ -615,7 +627,7 @@ class CoarseTransformer(nn.Module):
 
         pred_semantic_tokens, pred_coarse_tokens = tokens[:, :semantic_seq_len], tokens[:, (semantic_seq_len + 1):]
 
-        # get the eos token from predicted semantic tokens, and use that to predic tthe first coarse token
+        # get the eos token from predicted semantic tokens, and use that to predict the first coarse token
 
         semantic_eos = semantic_token_ids == self.semantic_eos_id
         pred_semantic_eos_tokens = tokens[:, 1:(semantic_seq_len + 1)][semantic_eos]
